@@ -79,7 +79,11 @@ simHierData <- function(nbAnimals=1,hierStates,hierDist,
     }
     oldDoPar <- doFuture::registerDoFuture()
     on.exit(with(oldDoPar, foreach::setDoPar(fun=fun, data=data, info=info)), add = TRUE)
-    future::plan(future::multisession, workers = ncores)
+    if (Sys.getenv("CI") == "true" && grepl("macOS", Sys.getenv("RUNNER_OS"))) {
+      future::plan(future::sequential)
+    } else {
+      future::plan(future::multisession, workers = ncores)
+    }
     # hack so that foreach %dorng% can find internal momentuHMM variables without using ::: (frowned upon by CRAN)
     progBar <- progBar
     mvndists <- mvndists
