@@ -76,7 +76,11 @@ timeInStates.HMMfits <- function(m, by = NULL, alpha = 0.95, ncores = 1){
     }
     oldDoPar <- doFuture::registerDoFuture()
     on.exit(with(oldDoPar, foreach::setDoPar(fun=fun, data=data, info=info)), add = TRUE)
-    future::plan(future::multisession, workers = ncores)
+    if (Sys.getenv("CI") == "true" && grepl("macOS", Sys.getenv("RUNNER_OS"))) {
+      future::plan(future::sequential)
+    } else {
+      future::plan(future::multisession, workers = ncores)
+    }
     # hack so that foreach %dorng% can find internal momentuHMM variables without using ::: (forbidden by CRAN)
     progBar <- progBar
     get_combins <- get_combins
